==> biemond-orawls-1.0.31.tar.gz: biemond-orawls-1.0.31/lib/puppet/type/wls_jmsserver.rb <==
require 'easy_type'
require 'utils/wls_access'
require 'utils/settings'
require 'utils/title_parser'
require 'facter'

module Puppet
  newtype(:wls_jmsserver) do
    include EasyType
    include Utils::WlsAccess
    extend Utils::TitleParser

    desc 'This resource allows you to manage a jmsserver in an WebLogic domain.'

    ensurable

    set_command(:wlst)

    to_get_raw_resources do
      Puppet.info "index #{name}"
      environment = { 'action' => 'index', 'type' => 'wls_jmsserver' }
      wlst template('puppet:///modules/orawls/providers/wls_jmsserver/index.py.erb', binding), environment
    end

    on_create  do | command_builder |
      Puppet.info "create #{name} "
      template('puppet:///modules/orawls/providers/wls_jmsserver/create.py.erb', binding)
    end

    on_modify  do | command_builder |
      Puppet.info "modify #{name} "
      template('puppet:///modules/orawls/providers/wls_jmsserver/modify.py.erb', binding)
    end

    on_destroy  do | command_builder |
      Puppet.info "destroy #{name} "
      template('puppet:///modules/orawls/providers/wls_jmsserver/destroy.py.erb', binding)
    end

    parameter :domain
    parameter :name
    parameter :jmsserver_name
    parameter :timeout
    property :persistentstore
    property :persistentstoretype
    property :target
    property :targettype
    property :bytes_maximum
    property :store_enabled
    property :allows_persistent_downgrade

    add_title_attributes(:jmsserver_name) do
      /^((.*\/)?(.*)?)$/
    end

  end
end

==> biemond-orawls-1.0.57.tar.gz: biemond-orawls-1.0.57/lib/puppet/type/wls_jmsserver.rb <==
require File.dirname(__FILE__) + '/../../orawls_core'


module Puppet
  Type.newtype(:wls_jmsserver) do
    include EasyType
    include Utils::WlsAccess
    extend Utils::TitleParser

    desc 'This resource allows you to manage a jmsserver in an WebLogic domain.'

    ensurable

    set_command(:wlst)

    to_get_raw_resources do
      Puppet.debug "index #{name}"
      environment = { 'action' => 'index', 'type' => 'wls_jmsserver' }
      wlst template('puppet:///modules/orawls/providers/wls_jmsserver/index.py.erb', binding), environment
    end

    on_create  do | command_builder |
      wlst_action = 'create'
      Puppet.info "create #{name} "
      template('puppet:///modules/orawls/providers/wls_jmsserver/create_modify.py.erb', binding)
    end

    on_modify  do | command_builder |
      wlst_action = 'modify'
      Puppet.info "modify #{name} "
      template('puppet:///modules/orawls/providers/wls_jmsserver/create_modify.py.erb', binding)
    end

    on_destroy  do | command_builder |
      Puppet.info "destroy #{name} "
      template('puppet:///modules/orawls/providers/wls_jmsserver/destroy.py.erb', binding)
    end

    parameter :domain
    parameter :name
    parameter :jmsserver_name
    parameter :timeout
    property :persistentstore
    property :persistentstoretype
    property :target
    property :targettype
    property :bytes_maximum
    property :store_enabled
    property :allows_persistent_downgrade
    property :insertionpaused
    property :consumptionpaused
    property :productionpaused


    add_title_attributes(:jmsserver_name) do
      /^((.*\/)?(.*)?)$/
    end

  end
end
